@@ -25,11 +25,11 @@ __copyright__ = "Copyright 2022, Tony Fischer (tku137)"
 __license__ = "GPLv3"
 __email__ = "tonyfischer@mailbox.org"
 __status__ = "Development"
-__version__ = "2022.1.2"
+__version__ = "2022.2.1"
 __credits__ = ["Tony Fischer (tku137)", "Alexander Hayn"]
 
 __all__ = ['core', 'poresize', 'network', 'utils',
-           'get_binary', 'get_fiber_thickness', 'get_pore_sizes']
+           'get_binary', 'get_fiber_thickness', 'get_pore_sizes', 'get_fragmented_poresizes', 'calc_inhomogeneity']
 
 
 from . import core
@@ -38,4 +38,4 @@ from . import network
 from . import utils
 
 from .core import get_binary
-from .poresize import get_fiber_thickness, get_pore_sizes
+from .poresize import get_fiber_thickness, get_pore_sizes, get_fragmented_poresizes, calc_inhomogeneity
